Processor.processor.Listener.on_connecting — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.processor.Listener.on_connecting

Listener.on_connecting(host_and_port)

  Called by the STOMP connection once a TCP/IP connection to the STOMP server has been established or re-established. Note that at this point, no connection has been established on the STOMP protocol level. For this, you need to invoke the “connect” method on the connection.

  Parameters

    host_and_port ((str,int)) – a tuple containing the host name and port number to which the connection has been established.